<?php

namespace Service;

/**
 * Login Service
 * 
 * Connects to the Database to handle queries 
 * related to login processes. 
 *  
 * @author Rômulo Alves Lousada
 */
class Login 
{
    protected $connection;

    /**
     * Class constructor
     * 
     * Initialize an object's properties upon creation of the object.
     * 
     * @param Object $connection Object to manage database connection and queries
     * 
     * @return void
     * 
     * @access public
     * @author Rômulo Alves Lousada
     */
    public function __construct($connection) 
    {
        $this->connection = $connection;
    }

    /**
     * Retrieve user from database
     * 
     * Searches for a user in the database according to 
     * input parameters received.
     *
     * @param String $user Inputted value for user.
     *
     * @return Array
     * @throws Exception
     *
     * @access public
     * @author Rômulo Alves Lousada
     */
    public function getUser($user) 
    {
        try {
            $params = array(
                'CDOPERADOR' => $user,
                'DSEMAILOPER' => $user,
            );

            return $this->connection->fetchAll(\Util\Query::GET_USER, $params);
        } catch (\Exception $e) {
            throw 'Erro ao buscar usuário. Erro: '.$e->getMessage();
        }
    }

    /**
     * Retrieve user from database
     * 
     * Searches the user permissions in the database according to
     * received input parameters.
     *
     * @param String $operator Inputted value for user.
     *
     * @return Array
     * @throws Exception
     *
     * @access public
     * @author Marcos Souza
     */
    public function getOperatorGroupData($operator) 
    {
        try {
            $params = array(
                'CDOPERADOR' => $operator
            );

            return $this->connection->fetchAll(\Util\Query::GET_CONTROL_ACCESS_TAA, $params);
        } catch (\Exception $e) {
            throw 'Erro ao buscar permissoes do grupo de operador. Erro: '.$e->getMessage();
        }
    }
}